<?php

class FV_AddfundsController
{

    private static $payment;
    private static $fanvictor;
    private static $coupon;

    public function __construct()
    {
        self::$payment = new Payment();
        self::$fanvictor = new Fanvictor();
        self::$coupon = new FV_CouponModel();
    }

    public static function process()
    {
        add_action('wp_enqueue_scripts', array('FV_AddfundsController', 'theme_name_scripts'));
        add_filter('the_content', array('FV_AddfundsController', 'addContent'));
    }

    public static function theme_name_scripts()
    {
        wp_enqueue_script('ui.js', FANVICTOR__PLUGIN_URL_JS . 'ui.js');
        wp_enqueue_script('payment.js', FANVICTOR__PLUGIN_URL_JS . 'payment.js');
        wp_enqueue_style('ui.css', FANVICTOR__PLUGIN_URL_CSS . 'ui/ui.css');
        wp_enqueue_style('payment.css', FANVICTOR__PLUGIN_URL_CSS . 'payment.css');
        wp_enqueue_style('style.css', FANVICTOR__PLUGIN_URL_CSS . 'style.css');
    }

    public static function addContent()
    {
        if (!in_the_loop())
        {
            return;
        }
        if (isset($_SESSION['is_transaction']))
        {
            unset($_SESSION['is_transaction']);
        }
        if (isset($_SESSION['iFundHitoryId']))
        {
            unset($_SESSION['iFundHitoryId']);
        }
        if (isset($_SESSION['totalMoney']))
        {
            unset($_SESSION['totalMoney']);
        }

        $gatewayList = self::$payment->gatewayList();

        //check redirect if there is only one gateway
        $gateway_type = isset($_GET['type']) ? $_GET['type'] : "";
        $payout_gateways = get_option('fanvictor_payout_gateway');
        if ($payout_gateways == null)
        {
            FV_Redirect(FANVICTOR_URL_LOBBY, __('No available payment gateway, please contact admin.', 'fantasy-sports'));
        }
        if (count($payout_gateways) == 1)
        {
            $gateway_type = $payout_gateways[0];
        }
        if (isset($_GET['type']) && !self::$payment->isGatewayExist($gateway_type))
        {
            FV_Redirect(FANVICTOR_URL_LOBBY, __('Payment gateway not found', 'fantasy-sports'));
        }
        if ($gateway_type == FANVICTOR_GATEWAY_BITCOIN ||
                $gateway_type == FANVICTOR_GATEWAY_DFSCOIN ||
                $gateway_type == FANVICTOR_GATEWAY_FOOTYCASHCOIN)
        {
            wp_enqueue_script('currency.js', 'https://files.coinmarketcap.com/static/widget/currency.js');
        }

        //check can play
        $canplay = false;
        if (self::$fanvictor->canPlay())
        {
            $sUrlSubmit = FANVICTOR_URL_ADD_FUNDS;
            //$aGateways = self::$payment->viewGateway();
            $canplay = true;
        }
        $isHasCoupon = self::$coupon->isHasCoupon(CP_ACTION_EXTRA_DEPOSIT) || self::$coupon->isHasCoupon(CP_ACTION_ADD_MONEY);
        $fee_percentage = (int) get_option('fanvictor_fee_percentage');
        $country_list = self::$fanvictor->getCountryList();

        //auto update dfscoin exchange rate
        if (empty($_GET['type']))
        {
            $global_setting = self::$fanvictor->getGlobalSetting();
            if ($global_setting['multiple_currency_support'])
            {
                self::$fanvictor->updateCoinExchangeRate();
            }
        }

        //map gateway image
        $gateway_icons = array(
            FANVICTOR_GATEWAY_PAYPAL => "paypal.png",
            FANVICTOR_GATEWAY_PRIORITY => "priority.png",
            FANVICTOR_GATEWAY_FLUTTERWAVE => "flutterwave.png",
            FANVICTOR_GATEWAY_FTTECH => "fttech.png",
            FANVICTOR_GATEWAY_BILLMAP => "billmap.png",
            FANVICTOR_GATEWAY_BITCOIN => "bitcoin.png",
            FANVICTOR_GATEWAY_CHEESE => "cheesecoin.png",
            FANVICTOR_GATEWAY_MOLPAY => "molpay.png"
        );
        
        //set message for return url
        if(!empty($_GET['return_url']))
        {
            FV_SetMessage(__('Online payment was successfully completed and transaction is being processed', 'fantasy-sports'));
        }
        include FANVICTOR__PLUGIN_DIR_VIEW . 'addfunds.php';
    }
}

?>