<?php
class FV_ContestController
{
    private static $orgs;
    private static $pools;
    private static $playerposition;
    private static $players;
    private static $teams;
    private static $fanvictor;
    public function __construct() 
    {
        self::$orgs = new Organizations();
        self::$pools = new Pools();
        self::$playerposition = new PlayerPosition();
        self::$players = new Players();
        self::$teams = new Teams();
        self::$fanvictor = new Fanvictor();
    }
    
	public static function process()
	{    
        add_action( 'wp_enqueue_scripts', array('FV_ContestController', 'loadCssJs') );
        add_filter('the_content', array('FV_ContestController', 'contest'));
	}
    
    public static function loadCssJs()
    {
        $league_id = pageSegment(3);
        
        //league
        $league = self::$fanvictor->getLeagueDetail($league_id);
        if ($league == null)
        {
            FV_Redirect(FANVICTOR_URL_CREATE_CONTEST, __('Contest does not exist', 'fantasy-sports'), true);
        }
        $league = $league[0];
        
        wp_enqueue_script('global.js', FANVICTOR__PLUGIN_URL_JS . 'global.js');
        wp_enqueue_script('ui.js', FANVICTOR__PLUGIN_URL_JS.'ui.js');
        wp_enqueue_script('accounting.js', FANVICTOR__PLUGIN_URL_JS.'accounting.js');
        wp_enqueue_script('fanvictor.js', FANVICTOR__PLUGIN_URL_JS.'fanvictor.js');
        
        wp_enqueue_style('font-awesome.css', FANVICTOR__PLUGIN_URL_CSS.'font-awesome/css/font-awesome.css');
        wp_enqueue_style('global.css', FANVICTOR__PLUGIN_URL_CSS.'global.css');
        wp_enqueue_style('ui.css', FANVICTOR__PLUGIN_URL_CSS.'ui/admin-ui.css');
        wp_enqueue_style('style.css', FANVICTOR__PLUGIN_URL_CSS.'style.css');
        wp_enqueue_style('ui.css', FANVICTOR__PLUGIN_URL_CSS.'ui/admin-ui.css');
        wp_enqueue_style('playerdraft_contest.css', FANVICTOR__PLUGIN_URL_CSS.'playerdraft_contest.css');
        
        switch(strtolower($league['gameType']))
        {
            case "livedraft":
                wp_enqueue_script('playerdraft.js', FANVICTOR__PLUGIN_URL_JS.'playerdraft.js');
                wp_enqueue_script('livedraft.js', FANVICTOR__PLUGIN_URL_JS . 'livedraft.js');
                break;
            case "bracket":
                wp_enqueue_script('bracket.js', FANVICTOR__PLUGIN_URL_JS.'bracket.js');
                wp_enqueue_style('bracket.css', FANVICTOR__PLUGIN_URL_CSS.'bracket.css');
                break;
            case "minigoliath":
                wp_enqueue_script('minigoliath.js', FANVICTOR__PLUGIN_URL_JS.'minigoliath.js');
                break;
            case "goliath":
                wp_enqueue_script('goliath.js', FANVICTOR__PLUGIN_URL_JS.'goliath.js');
                break;
            case "roundpickem":
                wp_enqueue_script('roundpickem.js', FANVICTOR__PLUGIN_URL_JS.'roundpickem.js');
                break;
            case "pickmoney":
            case "picktie":
            case "pickspread":
            case "howmanygoals":
            case "bothteamstoscore":
            case "pickem":
                wp_enqueue_script('rankings.js', FANVICTOR__PLUGIN_URL_JS.'rankings.js');
                wp_enqueue_script('playerdraft.js', FANVICTOR__PLUGIN_URL_JS.'playerdraft.js', 5);
                wp_enqueue_script('pickem.js', FANVICTOR__PLUGIN_URL_JS.'pickem.js');
                break;
            default :
                wp_enqueue_script('playerdraft.js', FANVICTOR__PLUGIN_URL_JS.'playerdraft.js');
        }
    }
    
    public static function contest()
    {
        if(!in_the_loop())
        {
            return;
        }
        
        $league_id = pageSegment(3);
        $entry_number = !empty($_GET['num']) ? $_GET['num'] : 1;
        $league = self::$fanvictor->getLeagueDetail($league_id);
        $league = $league[0];
        
        switch(strtolower($league['gameType']))
        {
            case "livedraft":
                self::livedraft($league);
                break;
            case "bracket":
                self::bracket($league);
                break;
            case "minigoliath":
                self::minigoliath($league);
                break;
            case "goliath":
                self::goliath($league);
                break;
            case "roundpickem":
                self::roundPickem($league);
                break;
            case "pickmoney":
            case "picktie":
            case "pickspread":
            case "howmanygoals":
            case "bothteamstoscore":
            case "pickem":
                self::pickem($league);
                break;
            default :
                self::playerdraft($league);
        }
    }
    
    private static function playerdraft($league)
    {
        $leagueId = $league['leagueID'];
        $entry_number = !empty($_GET['num']) ? $_GET['num'] : 1;
        
        $result = self::$fanvictor->getContestResult($leagueId);
        $scoringCats = $result['scoring_cat'];
        $bonus = $result['bonus'];
        $aRounds = $result['rounds'];
        $aFights = $result['fights'];
        $league = self::$fanvictor->parseLeagueData($league);

        $aFights = self::$pools->parseFightsDataDetail($aFights);
        include FANVICTOR__PLUGIN_DIR_VIEW_ELEMENT.'result/playerdraft.php';
    }
    
    private static function livedraft($league)
    {
        $leagueId = $league['leagueID'];
        $entry_number = !empty($_GET['num']) ? $_GET['num'] : 1;
        
        $result = self::$fanvictor->getContestResult($leagueId);
        $scoringCats = $result['scoring_cat'];
        $bonus = $result['bonus'];
        $aRounds = $result['rounds'];
        $aFights = $result['fights'];
        
        $league = self::$fanvictor->parseLeagueData($league);
        $league = $league[0];

        $aFights = self::$pools->parseFightsDataDetail($aFights);
        $week = $result['week'];
        $week_select = $result['week_select'];
        $opponents = $result['opponents'];

        include FANVICTOR__PLUGIN_DIR_VIEW_ELEMENT.'result/livedraft.php';
    }
    
    private static function bracket($league)
    {
        $leagueId = $league['leagueID'];
        $entry_number = !empty($_GET['num']) ? $_GET['num'] : 1;
        
        $result = self::$fanvictor->getContestResult($leagueId);
        $bonus = $result['bonus'];
        $aFights = $result['fights'];
        $league = self::$fanvictor->parseLeagueData($league);

        $aFights = self::$pools->parseFightsDataDetail($aFights);
        include FANVICTOR__PLUGIN_DIR_VIEW_ELEMENT.'result/bracket.php';
    }
    
    private static function roundPickem($league)
    {
        $leagueID = pageSegment(3);
        $entry_number = !empty($_GET['num']) ? $_GET['num'] : 1;
        
        $data = self::$fanvictor->getRoundPickemCurrentWeek($leagueID, $entry_number);
        $current_week = $data['current_week'];
        
        include FANVICTOR__PLUGIN_DIR_VIEW_ELEMENT.'result/roundpickem.php';
    }
    
    private static function pickem($league)
    {
        $leagueID = pageSegment(3);
        $entry_number = !empty($_GET['num']) ? $_GET['num'] : 1;
        
        $global_settings = self::$fanvictor->getGlobalSetting();
        $allow_pick_email = $global_settings['allow_pick_email'];
        $number_of_weeks = array();
        $number_of_months = array();

        include FANVICTOR__PLUGIN_DIR_VIEW_ELEMENT.'result/pickem.php';
    }
    
    private static function goliath($league)
    {
        $league_id = pageSegment(3);
        $entry_number = !empty($_GET['num']) ? $_GET['num'] : 1;
        
        //get data
        $data = self::$fanvictor->getGoliathContestResult($league_id);
        $fights = $data['fights'];
        
        include FANVICTOR__PLUGIN_DIR_VIEW_ELEMENT.'result/goliath.php';
    }
    
    private static function minigoliath($league)
    {
        $league_id = pageSegment(3);
        $entry_number = !empty($_GET['num']) ? $_GET['num'] : 1;
        
        //get data
        $data = self::$fanvictor->getMiniGoliathContestResult($league_id);
        $fights = $data['fights'];
        
        include FANVICTOR__PLUGIN_DIR_VIEW_ELEMENT.'result/minigoliath.php';
    }
}
?>