<?php
class FV_EntryController
{
    private static $players;
    private static $fanvictor;

    public function __construct()
    {
        self::$players = new Players();
        self::$fanvictor = new Fanvictor();
    }

    public static function process()
    {
        add_action('wp_enqueue_scripts', array('FV_EntryController', 'loadCssJs'));
        add_filter('the_content', array('FV_EntryController', 'entry'));
    }
    
    public static function loadCssJs()
    {
        $league_id = pageSegment(3);
        
        //league
        $league = self::$fanvictor->getLeagueDetail($league_id);
        if ($league == null)
        {
            FV_Redirect(FANVICTOR_URL_CREATE_CONTEST, __('Contest does not exist', 'fantasy-sports'), true);
        }
        $league = $league[0];
        
        wp_enqueue_script('global.js', FANVICTOR__PLUGIN_URL_JS . 'global.js');
        switch (strtolower($league['gameType']))
        {
            case "bracket":
                wp_enqueue_style('bracket.css', FANVICTOR__PLUGIN_URL_CSS . 'bracket.css');
                wp_enqueue_script('bracket.js', FANVICTOR__PLUGIN_URL_JS . 'bracket.js');
                break;
            default :
                wp_enqueue_style('playerdraft.css', FANVICTOR__PLUGIN_URL_CSS . 'playerdraft.css');
                wp_enqueue_script('playerdraft.js', FANVICTOR__PLUGIN_URL_JS . 'playerdraft.js');
        }
    }

    public static function entry()
    {
        if (!in_the_loop())
        {
            return;
        }

        $league_id = pageSegment(3);
        $entry_number = !empty($_GET['num']) ? $_GET['num'] : 1;

        //league
        $league = self::$fanvictor->getLeagueDetail($league_id);
        if ($league == null)
        {
            FV_Redirect(FANVICTOR_URL_CREATE_CONTEST, __('Contest does not exist', 'fantasy-sports'), true);
        }
        $league = $league[0];
        if (!$league['is_mixing'] && $league['pool_status'] != 'NEW')
        {
            FV_Redirect(FANVICTOR_URL_CONTEST . $league_id, null, true);
        }
        else if ($league['is_mixing'] && $league['is_mixing_complete'])
        {
            FV_Redirect(FANVICTOR_URL_CONTEST . $league_id, null, true);
        }
        
        switch (strtolower($league['gameType']))
        {
            case "bracket":
                self::bracket($league);
                break;
            default :
                if ($league['is_racing'])
                {
                    self::racing($league);
                }
                else if ($league['is_horse'])
                {
                    self::horse($league);
                }
                else if ($league['is_mixing'])
                {
                    self::mixing($league);
                }
                else
                {
                    self::playerdraft($league);
                }
        }
    }

    private static function playerdraft($league)
    {
        //get prams
        $params = $_GET;
        $leagueID = $league['leagueID'];
        $entry_number = isset($_GET['num']) ? $_GET['num'] : 1;

        $data = self::$fanvictor->getGameEntryData($leagueID, $entry_number);
        $is_lineup_scoccer_field = isset($data['is_soccer']) && $data['is_lineup_scoccer_field'] ? $data['is_soccer'] : false;
		if (empty($data['players']))
        {
            FV_Redirect(FANVICTOR_URL_LOBBY, __("You haven't picked any player yet", 'fantasy-sports'), true);
        }
        $league = $data['league'];
        $aPool = $data['pool'];
        $aFights = $data['fights'];
        $aPlayers = $data['players'];
        $aPlayers = self::$players->parsePlayersData($aPlayers);
        $allow_pick_email = $data['allow_pick_email'];

        //cur user
        $current_user = wp_get_current_user();
        $user_avatar = self::$fanvictor->get_avatar_url(self::$fanvictor->get_avatar($_COOKIE['fanvictor_user_id'], 32));

        // get image
        $aNewPlayers = array();
        if ($is_lineup_scoccer_field)
        {
            foreach ($aPlayers as $player)
            {
                $aNewPlayers[$player['position']][] = $player;
            }
        }
        include FANVICTOR__PLUGIN_DIR_VIEW_ELEMENT . 'entry/normal.php';
    }

    private static function mixing($league)
    {
        //get prams
        $params = $_GET;
        $leagueID = $league['leagueID'];
        $entry_number = isset($_GET['num']) ? $_GET['num'] : 1;

        $data = self::$fanvictor->getMixingGameEntryData($leagueID, $entry_number);
        $league = $data['league'];
        $aPool = $data['pool'];
        $aFights = $data['fights'];
        $aPlayers = $data['players'];
        $aPlayers = self::$players->parsePlayersData($aPlayers);

        //cur user
        $current_user = wp_get_current_user();
        $user_avatar = self::$fanvictor->get_avatar_url(self::$fanvictor->get_avatar($_COOKIE['fanvictor_user_id'], 32));

        include FANVICTOR__PLUGIN_DIR_VIEW_ELEMENT . 'entry/mixing.php';
    }

    private static function horse($league)
    {
        //get prams
        $params = $_GET;
        $leagueID = $league['leagueID'];
        $entry_number = isset($_GET['num']) ? $_GET['num'] : 1;

        $data = self::$fanvictor->getGameEntryData($leagueID, $entry_number);
        $aPool = $data['pool'];
        $aFights = $data['fights'];
        $aPlayers = $data['players'];
        $aPlayers = self::$players->parsePlayersData($aPlayers);

        //cur user
        $current_user = wp_get_current_user();
        $user_avatar = self::$fanvictor->get_avatar_url(self::$fanvictor->get_avatar($_COOKIE['fanvictor_user_id'], 32));

        include FANVICTOR__PLUGIN_DIR_VIEW_ELEMENT . 'entry/horse.php';
    }

    private static function racing($league)
    {
        //get prams
        $params = $_GET;
        $leagueID = $league['leagueID'];
        $entry_number = isset($_GET['num']) ? $_GET['num'] : 1;

        $data = self::$fanvictor->getGameEntryData($leagueID, $entry_number);
        $aPool = $data['pool'];
        $aFights = $data['fights'];
        $aPlayers = $data['players'];
        $aPlayers = self::$players->parsePlayersData($aPlayers);

        //cur user
        $current_user = wp_get_current_user();
        $user_avatar = self::$fanvictor->get_avatar_url(self::$fanvictor->get_avatar($_COOKIE['fanvictor_user_id'], 32));

        include FANVICTOR__PLUGIN_DIR_VIEW_ELEMENT . 'entry/racing.php';
    }

    private static function bracket($league)
    {
        //get prams
        $params = $_GET;
        $entry_number = !empty($params['entry_number']) ? $params['entry_number'] : 1;

        //load data
        $data = self::$fanvictor->getBracketGame($league['leagueID'], $entry_number);
        $team_groups = $data['team_groups'];
        $my_picks = $data['my_picks'];
        list($group_left, $group_right) = self::$fanvictor->bracketGroupTeam($team_groups);

        //view
        include FANVICTOR__PLUGIN_DIR_VIEW_ELEMENT . 'entry/bracket.php';
    }
}

?>