<?php

class FV_GameController
{

    private static $orgs;
    private static $pools;
    private static $playerposition;
    private static $players;
    private static $teams;
    private static $fanvictor;
    private static $payment;

    public function __construct()
    {
        self::$payment = new Payment();
        self::$orgs = new Organizations();
        self::$pools = new Pools();
        self::$playerposition = new PlayerPosition();
        self::$players = new Players();
        self::$teams = new Teams();
        self::$fanvictor = new Fanvictor();
    }

    public static function process()
    {
        add_action('wp_enqueue_scripts', array('FV_GameController', 'loadCssJs'));
        
        //self::loadCssJs();
        if (isset($_GET['manage_trade_request']) && isset($_GET['league_id']) && $_GET['entry_number'])
        {
            add_filter('the_content', array('FV_GameController', 'liveDraftManageTradeRequest'));
        }
        elseif (isset($_GET['trade_target_id']) && isset($_GET['contest_id']) && isset($_GET['target_entry']) && isset($_GET['entry_number']))
        {
            add_filter('the_content', array('FV_GameController', 'liveDraftTradePlayer'));
        }
        elseif (isset($_GET['action'])/* && $_GET['action'] == 3 */)
        {
            //add_action('wp_enqueue_scripts', array('FV_GameController', 'live_draft_theme_name_scripts'));
            add_filter('the_content', array('FV_GameController', 'game'));
        }
        elseif (isset($_POST['submitPicks']))
        {
            if ($_POST["session_id"] == session_id())
            {
                add_filter('the_content', array('FV_GameController', 'submitPicks'));
            }
            else
            {
                FV_Redirect(FANVICTOR_URL_CREATE_CONTEST, __("Contest does not exist.", 'fantasy-sports'), true);
            }
        }
        else
        {
            add_filter('the_content', array('FV_GameController', 'game'));
        }
    }
    
    public static function loadCssJs()
    {
        $league_id = pageSegment(3);
        
        //league
        $league = self::$fanvictor->getLeagueDetail($league_id);
        if ($league == null)
        {
            FV_Redirect(FANVICTOR_URL_CREATE_CONTEST, __('Contest does not exist', 'fantasy-sports'), true);
        }
        $league = $league[0];
        
        wp_enqueue_script('global.js', FANVICTOR__PLUGIN_URL_JS . 'global.js');
        wp_enqueue_script('tablesorter.js', FANVICTOR__PLUGIN_URL_JS . 'tablesorter.js');
        wp_enqueue_script('ui.js', FANVICTOR__PLUGIN_URL_JS . 'ui.js');
        wp_enqueue_style('ui.css', FANVICTOR__PLUGIN_URL_CSS . 'ui/ui.css');
        wp_enqueue_style('font-awesome.css', FANVICTOR__PLUGIN_URL_CSS . 'font-awesome/css/font-awesome.css');
        wp_enqueue_style('style.css', FANVICTOR__PLUGIN_URL_CSS.'style.css');
        switch (strtolower($league['gameType']))
        {
            case 'livedraft':
                wp_enqueue_style('live_draft.css', FANVICTOR__PLUGIN_URL_CSS . 'live_draft.css');
                wp_enqueue_script('jquery.countdown.js', FANVICTOR__PLUGIN_URL_JS . 'jquery.countdown.js');
                wp_enqueue_script('countdown.min.js', FANVICTOR__PLUGIN_URL_JS . 'countdown.min.js');
                wp_enqueue_script('livedraft.js', FANVICTOR__PLUGIN_URL_JS . 'livedraft.js');
                wp_enqueue_script('live_draft_trade_player.js', FANVICTOR__PLUGIN_URL_JS . 'live_draft_trade_player.js');
                wp_enqueue_script('playerdraft.js', FANVICTOR__PLUGIN_URL_JS . 'playerdraft.js');
                wp_enqueue_script('loader.js', 'https://www.gstatic.com/charts/loader.js');
                break;
            case "bracket":
                wp_enqueue_style('bracket.css', FANVICTOR__PLUGIN_URL_CSS . 'bracket.css');
                wp_enqueue_script('bracket.js', FANVICTOR__PLUGIN_URL_JS . 'bracket.js');
                break;
            case "golfskin":
                self::validateForAllGameType($league, $entry_number);
                self::golfskin($league);
                break;
            case "roundpickem":
                wp_enqueue_script('roundpickem.js', FANVICTOR__PLUGIN_URL_JS.'roundpickem.js');
                break;
            case "picksquares":
                wp_enqueue_script('picksquares.js', FANVICTOR__PLUGIN_URL_JS.'picksquares.js');
                break;
            case "pickultimate":
                wp_enqueue_script('pickultimate.js', FANVICTOR__PLUGIN_URL_JS.'pickultimate.js');
                break;
            case "pickmoney":
            case "picktie":
            case "pickspread":
            case "howmanygoals":
            case "bothteamstoscore":
            case "pickem":
                wp_enqueue_script('pickem.js', FANVICTOR__PLUGIN_URL_JS.'pickem.js');
                break;
            case "goliath":
                wp_enqueue_script('goliath.js', FANVICTOR__PLUGIN_URL_JS.'goliath.js');
                break;
            case "minigoliath":
                wp_enqueue_script('minigoliath.js', FANVICTOR__PLUGIN_URL_JS.'minigoliath.js');
                break;
            default :
                wp_enqueue_script('loader.js', 'https://www.gstatic.com/charts/loader.js');
                wp_enqueue_script('playerdraft.js', FANVICTOR__PLUGIN_URL_JS . 'playerdraft.js');
                wp_enqueue_script('playerdraft_init.js', FANVICTOR__PLUGIN_URL_JS . 'playerdraft_init.js');
        }
    }

    public static function game()
    {
        if (!in_the_loop())
        {
            return;
        }

        $league_id = pageSegment(3);
        $entry_number = !empty($_GET['num']) ? $_GET['num'] : 1;
        
        //league
        $league = self::$fanvictor->getLeagueDetail($league_id);
        $league = $league[0];

        if (!self::$payment->isUserEnoughMoneyToJoin($league['entry_fee'], $league_id, $entry_number, $league['multi_entry']))
        {
            FV_Redirect(FANVICTOR_URL_ADD_FUNDS, __('You do not have enough funds to enter. Please add funds', 'fantasy-sports'), true);
        }
        switch (strtolower($league['gameType']))
        {
            case 'livedraft':
                self::livedraft($league);
                break;
            case "bracket":
                self::validateForAllGameType($league, $entry_number);
                self::bracket($league);
                break;
            case "golfskin":
                self::validateForAllGameType($league, $entry_number);
                self::golfskin($league);
                break;
            case "roundpickem":
                self::validateForAllGameType($league, $entry_number);
                self::roundPickem($league);
                break;
            case "picksquares":
                self::validateForAllGameType($league, $entry_number);
                self::picksquares($league);
                break;
            case "pickultimate":
                self::validateForAllGameType($league, $entry_number);
                self::pickultimate($league);
                break;
            case "pickmoney":
            case "picktie":
            case "pickspread":
            case "howmanygoals":
            case "bothteamstoscore":
            case "pickem":
                self::validateForAllGameType($league, $entry_number);
                self::pickem($league);
                break;
            case "goliath":
                self::validateForAllGameType($league, $entry_number);
                self::validateEnterGoliath($league, $entry_number);
                self::goliath($league);
                break;
            case "minigoliath":
                self::validateForAllGameType($league, $entry_number);
                self::validateEnterMiniGoliath($league, $entry_number);
                self::minigoliath($league);
                break;
            default :
                self::validateForAllGameType($league, $entry_number);
                if ($league['is_racing'])
                {
                    
                    self::racing($league);
                }
                else if ($league['is_horse'])
                {
                    self::horse($league);
                }
                else if ($league['is_motocross'])
                {
                    self::motocross($league);
                }
                else if ($league['is_mixing'])
                {
                    self::mixing($league);
                }
                else
                {
                    self::playerdraft($league);
                }
        }
    }
    
    private static function validateForAllGameType($league, $entry_number)
    {
        if($league == null)
        {
            FV_Redirect(FANVICTOR_URL_LOBBY, __('Contest does not exist', 'fantasy-sports'), true);
        }
        $league_id = $league['leagueID'];
        
        $data = self::$fanvictor->validateForAllGameType($league_id, $entry_number);
        if(!$data['success'])
        {
            switch ($data['code']) {
                
                case 1:
                    $message = __('Contest does not exist', 'fantasy-sports');
                    break;
                case 2:
                    $message = __('This contest has ended', 'fantasy-sports');
                    break;
                case 3:
                    $message = __('Sorry! This contest is full', 'fantasy-sports');
                    break;
                case 4:
                    $message = __('You reached maximum number of multi entries', 'fantasy-sports');
                    break;
                case 5:
                    $message = __('Only users who entered 50 contests or less can join this contest', 'fantasy-sports');
                    break;
                default :
                    $message = __('Unknown error', 'fantasy-sports');
            }
            FV_Redirect(FANVICTOR_URL_LOBBY, $message, true);
        }
        
        //validate for make bet
        $makeBet = true;
        if($league['entry_fee'] > 0)
        {
            $makeBet = self::$payment->isMakeBetForLeague($league_id, $entry_number);
            if (!$makeBet && !self::$payment->isUserEnoughMoneyToJoin($league['entry_fee'], $league_id, $entry_number, $league['multi_entry'])) 
            {
                FV_Redirect(FANVICTOR_URL_LOBBY, __('You do not have enough funds to enter. Please add funds', 'fantasy-sports'), true);
            }
        }
    }

    private static function golfskin($league)
    {
        $leagueId = pageSegment(3);
        $entry_number = isset($_GET['num']) ? $_GET['num'] : 0;
        $orgId = $league['organizationID'];

        $data = self::$fanvictor->getEnterGameData($leagueId, $entry_number, 0, $orgId);
        $league = self::$fanvictor->parseLeagueData($league);
        $aPool = $data['pool'];
        $aFights = $data['fights'];
        $aRounds = $data['rounds'];
        $aPositions = $data['positions'];
        $aLineups = $data['lineup'];
        $aTeams = $data['teams'];
        $indicators = $data['indicators'];
        $playerIdPicks = $data['playerIdPicks'];
        $otherLeagues = $data['otherLeagues'];
        $aPlayers = $data['players'];
        $aPlayers = self::$players->parsePlayersData($aPlayers);
        $aPlayerGolfSkin = $data['golfskinPlayers'];

        $total_money = 0;
        $entry_fee = $league['entry_fee'];
        $is_entry_fee = 0;
        if ($entry_fee > 0)
        {
            $is_entry_fee = 1;
        }
        if (!is_array($aPlayerGolfSkin))
        {
            $tmp_array = json_decode($aPlayerGolfSkin, true);
            foreach ($tmp_array as $players)
            {
                $total_money += count($players);
            }
        }
        if (is_array($aPlayerGolfSkin))
        {
            $aPlayerGolfSkin = json_encode($aPlayerGolfSkin);
        }

        include FANVICTOR__PLUGIN_DIR_VIEW_ELEMENT . 'gametype/golfskin.php';
    }

    private static function motocross($league)
    {
        $leagueId = pageSegment(3);
        $entry_number = isset($_GET['num']) ? $_GET['num'] : 0;
        $orgId = $league['organizationID'];

        $data = self::$fanvictor->getEnterGameData($leagueId, $entry_number, 0, $orgId);
        $league = self::$fanvictor->parseLeagueData($league);
        $aPool = $data['pool'];
        $aFights = $data['fights'];
        $aRounds = $data['rounds'];
        $aPositions = $data['positions'];
        $aLineups = $data['lineup'];
        $aTeams = $data['teams'];
        $indicators = $data['indicators'];
        $playerIdPicks = $data['playerIdPicks'];
        $otherLeagues = $data['otherLeagues'];
        $aPlayers = $data['players'];
        $aPlayers = self::$players->parsePlayersData($aPlayers);

        include FANVICTOR__PLUGIN_DIR_VIEW_ELEMENT . 'gametype/motocross.php';
    }

    private static function playerdraft($league)
    {
        $leagueId = pageSegment(3);
        $entry_number = isset($_GET['num']) ? $_GET['num'] : 0;
        $orgId = $league['organizationID'];
        #action 1: edit injury player
        #action 2: edit player each week
        $action = 0;
        if (isset($_GET['action']) && $_GET['action'] != 0)
        {
            $action = $_GET['action'];
        }
        $data = self::$fanvictor->getEnterGameData($leagueId, $entry_number, $action, $orgId);

        $is_soccer = false;
        $is_soccer_flex = false;
        $is_soccer_field = false;
        $is_position_step = false;
        $is_lineup_scoccer_field = false;
        $privater_id = "";

        $league = self::$fanvictor->parseLeagueData($league);
        $aPool = $data['pool'];
        $aFights = $data['fights'];
        $aRounds = $data['rounds'];
        $aPositions = $data['positions'];
        $aLineups = $data['lineup'];
        $aTeams = $data['teams'];
        $indicators = $data['indicators'];
        $playerIdPicks = $data['playerIdPicks'];
        $otherLeagues = $data['otherLeagues'];
        $aPlayers = $data['players'];
        $aPlayers = self::$players->parsePlayersData($aPlayers);
        $is_soccer = $data['is_soccer'];
        $is_soccer_flex = $data['is_soccer_flex'];
        $is_soccer_field = $data['is_soccer_field'];
        $privater_id = isset($data['privateer_id']) ? $data['privateer_id'] : $privater_id;
        $is_lineup_scoccer_field = isset($data['is_soccer']) && $data['is_lineup_scoccer_field'] ? $data['is_soccer'] : $is_lineup_scoccer_field;
        $is_position_step = isset($data['is_position_step']) ? $data['is_position_step'] : $is_position_step;

        $allow_change_bg = self::$fanvictor->checkAllowChangeBackground();
        $allow_change_bg = $allow_change_bg['is_allow'];
        if ($allow_change_bg)
        {
            $newPlayers = self::eliminateTeamOponent($data['fights'], $aPlayers);
            $aPlayers = $newPlayers;
        }
        $extra_positions = array();
        if ($is_soccer_flex)
        {
            foreach ($aPositions as $position)
            {
                if ($position['is_extra'])
                {
                    $extra_positions[] = array('position_id' => $position['id'], 'quantity' => $position['default_quantity']);
                }
            }
        }

        if (($is_lineup_scoccer_field || $is_position_step) && $aLineups != null && is_array($aLineups))
        {
            foreach ($aLineups as $pos)
            {
                if (!$pos['name'] || !$pos['enable'])
                {
                    continue;
                }
                $list_postion_soccer[$pos['id']] = array('default_quantity' => $pos['total'], 'current_quantity' => 0);
            }
        }

        include FANVICTOR__PLUGIN_DIR_VIEW_ELEMENT . 'gametype/playerdraft.php';
    }

    public static function eliminateTeamOponent($aFights, $aPlayers)
    {
        global $wpdb;
        $tb_user_teams = $wpdb->prefix . 'user_teams';
        $user_id = $_COOKIE['fanvictor_user_id'];
        if (empty($user_id))
        {
            return $aPlayers;
        }
        if (empty($aPlayers))
        {
            return $aPlayers;
        }
        $data = $wpdb->get_row("SELECT * FROM $tb_user_teams WHERE user_id= $user_id", ARRAY_A);
        if (empty($data))
        {
            return $aPlayers;
        }
        $team_id = $data['team_id'];
        $aNewPlayers = array();
        foreach ($aPlayers as $k => $player)
        {
            if ($player['teamID1'] == $team_id || $player['teamID2'] == $team_id)
            {
                if ($player['team_id'] != $team_id)
                {
                    unset($aPlayers[$k]);
                }
            }
        }
        foreach ($aPlayers as $k => $player)
        {
            $aNewPlayers[] = $player;
        }
        return $aNewPlayers;
    }

    public static function submitPicks()
    {
        $entry_number = $_POST['entry_number'];
        $league_id = $_POST['leagueID'];
        $action = 0;
        if (isset($_POST['action']) && !empty($_POST['action']))
        {
            $action = $_POST['action'];
        }

        //check valid data
        $valid = self::validData();

        //get league data
        $league = self::$fanvictor->getLeagueDetail($league_id);

        //validate
        if ($league == null)
        {
            FV_Redirect(FANVICTOR_URL_CREATE_CONTEST, __('Contest does not exist', 'fantasy-sports'), true);
            exit;
        }
        $league = $league [0];
        $makeBet = self::$payment->isMakeBetForLeague($league['leagueID'], $entry_number);
        if (!$makeBet && !self::$payment->isUserEnoughMoneyToJoin($league['entry_fee'], $league_id, $entry_number, $league['multi_entry']))
        {
            FV_Redirect(FANVICTOR_URL_ADD_FUNDS, __('You do not have enough funds to enter. Please add funds', 'fantasy-sports'), true);
            exit;
        }


        //insert pick
        $data = array('leagueID' => $_POST['leagueID'],
            'player_id' => $_POST['player_id'],
            'entry_number' => $entry_number,
            'player_position' => $_POST['player_position'],
            'injury' => isset($_POST['injury']) ? $_POST['injury'] : "",
            'action' => $action);
        $entry_number = self::$fanvictor->insertPlayerPicks($data);

        if (isset($entry_number['error']))
        {
            switch ($entry_number['error'])
            {
                case 1:
                    FV_Redirect(FANVICTOR_URL_MY_LIVE_ENTRIES, __('Your time to select a player has expired.  Your selection was randomly selected by the system', 'fantasy-sports'), true);
                    exit;
                    break;
                case 2:
                    FV_Redirect(FANVICTOR_URL_MY_LIVE_ENTRIES, __('You have reached the maximum changes you can make per week', 'fantasy-sports'), true);
                    exit;
                    break;
            }
        }
        if ($entry_number > 0)
        {
            if ($makeBet == false)
            {
                //decrease user money
                self::$payment->updateUserBalance($league['entry_fee'], true, $league['leagueID']);

                //add to history
                $aUser = self::$payment->getUserData();
                $params = array(
                    'amount' => $league['entry_fee'],
                    'leagueID' => $league['leagueID'],
                    'new_balance' => $aUser['balance'],
                    'operation' => 'DEDUCT',
                    'type' => 'MAKE_BET',
                    'entry_number' => $entry_number,
                    'status' => 'completed'
                );
                self::$payment->addFundhistory($params);
            }

            //trade player
            if ($makeBet !== false && $league['entry_fee'] > 0 && $valid != 9 && $league["trade_player"] && $league["is_live"] && !$league["trade_pick"])
            {
                $cost = $league['entry_fee'] / 2;
                //decrease user money
                self::$payment->updateUserBalance($cost, true, $league['leagueID']);

                //add to history
                $aUser = self::$payment->getUserData();
                $params = array(
                    'amount' => $cost,
                    'leagueID' => $league['leagueID'],
                    'new_balance' => $aUser['balance'],
                    'operation' => 'DEDUCT',
                    'type' => 'MAKE_BET',
                    'entry_number' => $entry_number,
                    'reason' => 'Change player',
                    'status' => 'completed'
                );
                self::$payment->addFundhistory($params);
            }

            if (!$league["trade_player"])
            {
                $_SESSION['showInviteFriends' . $league['leagueID']] = true;
            }
            self::$fanvictor->sendUserPickEmail($_POST['leagueID'], $_COOKIE['fanvictor_user_id'], $entry_number);

            //buddy press integration
            if ($league != null)
            {
                self::$fanvictor->addEnterContestActivity($league, $_COOKIE['fanvictor_user_id']);
            }

            //push notification for user who joined contest
            $fanvictor_firebase_apikey = get_option('fanvictor_firebase_apikey');
			$fanvictor_firebase_senderid = get_option('fanvictor_firebase_senderid');
			if(!empty($fanvictor_firebase_apikey) || !empty($fanvictor_firebase_senderid))
            {
                $user_ids = self::$fanvictor->getUserIdsJoinContest($league['leagueID'], $_COOKIE['fanvictor_user_id']);
                if (!empty($user_ids['user_ids']))
                {
                    self::$fanvictor->sendNotificationUserJoinContest($user_ids['user_ids'], $_COOKIE['fanvictor_user_id'], $league['name'], FANVICTOR_URL_CONTEST . $league['leagueID'] . "?num=" . $entry_number);
                }
            }

            if ($action == 1)
            {
                FV_Redirect(FANVICTOR_URL_MY_LIVE_ENTRIES, null, true);
                exit;
            }
            FV_Redirect(FANVICTOR_URL_ENTRY . $_POST['leagueID'] . "/?num=" . $entry_number, null, true);
        }
        FV_Redirect(FANVICTOR_URL_GAME . $_POST['leagueID'], __('Something went wrong! Please try again.', 'fantasy-sports'), true);
    }

    private static function validData()
    {
        $leagueID = $_POST['leagueID'];
        $entry_number = $_POST['entry_number'];
        //league
        $league = self::$fanvictor->getLeagueDetail($leagueID);

        //valid
        $isMixing = $league[0]['is_mixing'];

        if ($isMixing)
        { // mixing game
            $valid = self::$fanvictor->validEnterMixingPlayerdraft($_POST['leagueID'], $_POST['player_id']);
        }
        else
        { // single game
            $valid = self::$fanvictor->validEnterPlayerdraft($_POST['leagueID'], $_POST['player_id']);
        }

        switch ($valid)
        {
            case 2:
                FV_Redirect(FANVICTOR_URL_CREATE_CONTEST, __("This contest has ended", 'fantasy-sports'), true);
                break;
            case 3:
                FV_Redirect(FANVICTOR_URL_CREATE_CONTEST, __('Contest does not exist', 'fantasy-sports'), true);
                break;
            case 4:
                FV_Redirect(FANVICTOR_URL_CREATE_CONTEST, __('Sorry! This contest is full', 'fantasy-sports'), true);
                break;
            case 5:
                FV_Redirect(FANVICTOR_URL_GAME . $leagueID, __("Your team has exceeded this game's salary cap. Please change your team so it fits under the salary cap before entering", 'fantasy-sports'), true);
                break;
            case 6:
                FV_Redirect(FANVICTOR_URL_GAME . $leagueID, __("Please select a player for each position", 'fantasy-sports'), true);
                break;
            case 7:
                FV_Redirect(FANVICTOR_URL_GAME . $leagueID, __("You can not pick players of started game", 'fantasy-sports'), true);
                break;
            case 8:
                FV_Redirect(FANVICTOR_URL_GAME . $leagueID, __("You are only able to change one player", 'fantasy-sports'), true);
                break;
            case 10:
                FV_Redirect(FANVICTOR_URL_GAME . $leagueID, __("One of these players already picked by other users. Please select other players.", 'fantasy-sports'), true);
                break;
            case 12:
                FV_Redirect(FANVICTOR_URL_LOBBY, __('Only users who entered 50 contests or less can join this contest.', 'fantasy-sports'), true);
                break;
            case 13:
                FV_Redirect(FANVICTOR_URL_GAME . $leagueID, __('Your picks has exceeded player limitation per team.', 'fantasy-sports'), true);
                break;
            case 14:
                FV_Redirect(FANVICTOR_URL_LOBBY, __('You reached maximum number of multi entries.', 'fantasy-sports'), true);
                break;
        }

        if (!self::$payment->isUserEnoughMoneyToJoin($league[0]['entry_fee'], $leagueID, $entry_number, $league[0]['multi_entry']))
        {
            FV_Redirect(FANVICTOR_URL_ADD_FUNDS, __('You do not have enough funds to enter. Please add funds', 'fantasy-sports'), true);
        }
        if ($valid != 9)
        {
            if ($valid == 11)
            { // for trade player
                if (!self::$payment->isUserEnoughMoneyToChangePlayer($league[0]['entry_fee'] / 2))
                {
                    FV_Redirect(FANVICTOR_URL_ADD_FUNDS, __('You do not have enough funds to change players. Please add funds', 'fantasy-sports'), true);
                }
            }
        }
        return $valid;
    }

    private static function golfskinSubmitPicks()
    {
        self::golfskinValidata();
        $entry_number = $_POST['entry_number'];
        $data = array('leagueID' => $_POST['leagueID'],
            'players' => $_POST['players'],
            'poolID' => $_POST['poolID'],
            'entry_number' => $entry_number);
        $entry_number = self::$fanvictor->insertGolfSkinPlayerPicks($data);

        if ($entry_number > 0)
        {
            $league = self::$fanvictor->getLeagueDetail($_POST['leagueID']);
            $league = $league [0];
            $makeBet = self::$payment->isMakeBetForLeague($league['leagueID'], $entry_number);
            $total_money = $_POST['total_money'];

            if ($makeBet == false)
            {
                //decrease user money
                self::$payment->updateUserBalance($total_money, true, $league['leagueID']);
                //add to history
                $aUser = self::$payment->getUserData();
                $params = array(
                    'amount' => $total_money,
                    'leagueID' => $league['leagueID'],
                    'new_balance' => $aUser['balance'],
                    'operation' => 'DEDUCT',
                    'type' => 'MAKE_BET',
                    'entry_number' => $entry_number,
                    'status' => 'completed'
                );
                self::$payment->addFundhistory($params);
            }
            else
            {
                // update
                $diff_balance = $makeBet['amount'] - $total_money;
                if ($diff_balance != 0)
                {
                    //update balance
                    $status = ($diff_balance > 0) ? false : true;
                    self::$payment->updateUserBalance($diff_balance, $status, $league['leagueID']);


                    $payout_percentage = get_option('fanvictor_winner_percent');
                    $site_profit = $total_money * (100 - $payout_percentage) / 100;
                    $aValues['site_profit'] = $site_profit;
                    self::$payment->updateFundhistory($makeBet['fundshistoryID'], $aValues, null, 'DEDUCT');
                }
            }
            $_SESSION['showInviteFriends' . $league['leagueID']] = true;
            $_SESSION['userPicksInfo'] = array($_POST['leagueID'], get_current_user_id(), $entry_number);
            FV_Redirect(FANVICTOR_URL_ENTRY . $_POST['leagueID'] . "/?num=" . $entry_number, null, true);
        }
        FV_Redirect(FANVICTOR_URL_GAME . $_POST['leagueID'], __('Something went wrong! Please try again.', 'fantasy-sports'), true);
    }

    private static function golfskinValidata()
    {
        //league
        $league = self::$fanvictor->getLeagueDetail($_POST['leagueID']);
        //valid
        $valid = self::$fanvictor->validEnterGolfSkin($_POST['leagueID'], $_POST['player_id']);

        switch ($valid)
        {
            case 2:
                FV_Redirect(FANVICTOR_URL_CREATE_CONTEST, __("This contest has ended", 'fantasy-sports'), true);
                break;
            case 3:
                FV_Redirect(FANVICTOR_URL_CREATE_CONTEST, __('Contest does not exist', 'fantasy-sports'), true);
                break;
            case 4:
                FV_Redirect(FANVICTOR_URL_CREATE_CONTEST, __('Sorry! This contest is full', 'fantasy-sports'), true);
                break;
            case 5:
                FV_Redirect(FANVICTOR_URL_GAME . $league[0]['leagueID'], __("Please select at least one player for each round", 'fantasy-sports'), true);
                break;
        }
    }

    public static function liveDraftParseTradeString($list_players, $players)
    {

        foreach ($list_players as $player_id)
        {
            $player_name = $players[$player_id]['player_name'];
            $position_name = $players[$player_id]['position_name'];
            $str[] = "($position_name) $player_name";
        }
        return implode(',', $str);
    }

    //////////////////////live draft//////////////////////
    private static function livedraft($league)
    {
        $leagueId = pageSegment(3);
        $entry_number = isset($_GET['num']) ? $_GET['num'] : 0;
        #action 1: edit injury player
        #action 2: edit player each week
        $action = 0;
        if (isset($_GET['action']) && $_GET['action'] != 0)
        {
            $action = $_GET['action'];
        }

        $data = self::$fanvictor->getEnterLiveDraftGameData($leagueId, $entry_number, $action);

        switch ($data)
        {
            case 2:
                FV_Redirect(FANVICTOR_URL_CREATE_CONTEST, __('Contest does not exist', 'fantasy-sports'), true);
                break;
            case 3:
                FV_Redirect(FANVICTOR_URL_CONTEST . $leagueId, null, true);
                break;
            case 4:
                FV_Redirect(FANVICTOR_URL_CREATE_CONTEST, __('Sorry! This contest was full', 'fantasy-sports'), true);
                break;
            case 5:
                if (!self::$payment->isUserEnoughMoneyToJoin($league['entry_fee'], $leagueId, $entry_number, $league['multi_entry']))
                {
                    FV_Redirect(FANVICTOR_URL_LOBBY, __('You do not have enough funds to enter. Please add funds.', 'fantasy-sports'), true);
                }
                $result = self::$fanvictor->joinLiveDraftContest($leagueId);
                if ($result == 1)
                {
                    //decrease user money
                    self::$payment->updateUserBalance($league['entry_fee'], true, $league['leagueID']);

                    //add to history
                    $aUser = self::$payment->getUserData();
                    $params = array(
                        'amount' => $league['entry_fee'],
                        'leagueID' => $league['leagueID'],
                        'new_balance' => $aUser['balance'],
                        'operation' => 'DEDUCT',
                        'type' => 'MAKE_BET',
                        'entry_number' => $entry_number,
                        'status' => 'completed'
                    );
                    self::$payment->addFundhistory($params);
                    FV_Redirect(FANVICTOR_URL_LOBBY, __('you have successfully joined the contest - please log in at draft time to join the draft.', 'fantasy-sports'), true);
                }
                else
                {
                    FV_Redirect(FANVICTOR_URL_LOBBY, __('Something went wrong! Please try again.', 'fantasy-sports'), true);
                }
                break;
            case 6:
                FV_Redirect(FANVICTOR_URL_LOBBY, __('You have already joined this contest.', 'fantasy-sports'), true);
                break;
            case 7:
                FV_Redirect(FANVICTOR_URL_LOBBY, __('You are not allowed to draft player at this time.', 'fantasy-sports'), true);
                break;
            case 8:
                FV_Redirect(FANVICTOR_URL_LOBBY, __('Draft time has finished.', 'fantasy-sports'), true);
                break;
            case 9:
                FV_Redirect(FANVICTOR_URL_LOBBY, __('You can not change bench players at this time.', 'fantasy-sports'), true);
                break;
        }

        $league = $data['league'];
        $league = self::$fanvictor->parseLeagueData(array($league));
        $league = $league[0];
        $aPool = $data['pool'];
        $aFights = $data['fights'];
        $aRounds = $data['rounds'];
        $aPositions = $data['positions'];
        $aLineups = $data['lineup'];
        $aTeams = $data['teams'];
        $indicators = $data['indicators'];
        $playerIdPicks = $data['playerIdPicks'];
        $aPlayers = $data['players'];
        $aPlayers = self::$players->parsePlayersData($aPlayers);
        $limit_players = $data['limit_players'];
        $edit_injury_players = isset($data['edit_injury_players']) ? $data['edit_injury_players'] : false;
        $list_injury_players = isset($data['injury_players']) ? $data['injury_players'] : array();
        $allow_waiver_wire = $data['allow_waiver_wire'];
        $time_remaning = $data['time_remaning'];
        $except_player_ids = $data['except_player_ids'];
        $allow_live_draft = $data['allow_live_draft'];

        $allow_injury_position = array();
        if ($edit_injury_players)
        {
            foreach ($aPlayers as $player)
            {
                if (in_array($player['id'], $playerIdPicks) && $player['indicator_id'] == 1)
                {
                    $allow_injury_position[] = $player['position_id'];
                }
            }
        }
        include FANVICTOR__PLUGIN_DIR_VIEW_ELEMENT. 'gametype/livedraft.php';
    }
    
    public static function liveDraftManageTradeRequest()
    {
        if (!in_the_loop())
        {
            return;
        }
        $leagueID = $_GET['league_id'];
        $entry_number = $_GET['entry_number'];

        $result = self::$fanvictor->liveDraftRequestTradePlayertList($leagueID, $entry_number);
        $user_profile = self::$fanvictor->get_user_info($_COOKIE['fanvictor_user_id']);
        include FANVICTOR__PLUGIN_DIR_VIEW . 'type_game/live_draft_manage_tradeplayers.php';
    }

    public static function liveDraftTradePlayer()
    {
        if (!in_the_loop())
        {
            return;
        }
        //valid data
        $valid = self::$fanvictor->liveDraftValidTradePlayer($_GET);
        switch ($valid)
        {
            case 2:
                FV_Redirect(FANVICTOR_URL_MY_LIVE_ENTRIES, __("You cannot change a player with yourself", 'fantasy-sports'), true);
                break;
            case 3:
                FV_Redirect(FANVICTOR_URL_MY_LIVE_ENTRIES, __("The requested user does not exist", 'fantasy-sports'), true);
                break;
        }

        //get data
        $target_id = $_GET['trade_target_id'];
        $contest_id = $_GET['contest_id'];
        $entry_number = $_GET['entry_number'];
        $target_entry = $_GET['target_entry'];
        $profiles_user = self::$fanvictor->get_user_info($_COOKIE['fanvictor_user_id']);
        $profile_target = self::$fanvictor->get_user_info($target_id);
        $data = self::$fanvictor->liveDraftGetDataTradePlayer($target_id, $contest_id, $entry_number, $target_entry);

        $user_players = self::$players->parsePlayersData($data['user']);
        $target_players = self::$players->parsePlayersData($data['target']);
        $pool = $data['pool'];
        $is_requested = $data['is_requested'];

        include FANVICTOR__PLUGIN_DIR_VIEW . 'type_game/live_draft_tradeplayers.php';
    }
    //////////////////////end live draft//////////////////////
    
    //////////////////////racing//////////////////////
    private static function racing($league)
    {
        $leagueId = pageSegment(3);
        $entry_number = isset($_GET['num']) ? $_GET['num'] : 0;

        $data = self::$fanvictor->getEnterRacingGameData($leagueId, $entry_number);
        $aPool = $data['pool'];
        $aRounds = $data['rounds'];
        $aPositions = $data['positions'];
        $aLineups = $data['lineup'];
        $indicators = $data['indicators'];
        $playerIdPicks = $data['playerIdPicks'];
        $otherLeagues = $data['otherLeagues'];
        $aPlayers = $data['players'];
        $aPlayers = self::$players->parsePlayersData($aPlayers);

        include FANVICTOR__PLUGIN_DIR_VIEW_ELEMENT . 'gametype/racing.php';
    }

    //////////////////////end racing//////////////////////
    
    //////////////////////horse//////////////////////
    private static function horse($league)
    {
        $leagueId = pageSegment(3);
        $entry_number = isset($_GET['num']) ? $_GET['num'] : 0;
        $orgId = $league['organizationID'];

        $data = self::$fanvictor->getEnterGameData($leagueId, $entry_number, 0, $orgId);
        $league = self::$fanvictor->parseLeagueData($league);
        $aPool = $data['pool'];
        $aFights = $data['fights'];
        $aRounds = $data['rounds'];
        $aPositions = $data['positions'];
        $aLineups = $data['lineup'];
        $aTeams = $data['teams'];
        $indicators = $data['indicators'];
        $playerIdPicks = $data['playerIdPicks'];
        $otherLeagues = $data['otherLeagues'];
        $aPlayers = $data['players'];
        $aPlayers = self::$players->parsePlayersData($aPlayers);

        include FANVICTOR__PLUGIN_DIR_VIEW_ELEMENT . 'gametype/horse.php';
    }

    //////////////////////end horse//////////////////////
    
    //////////////////////mixing sport//////////////////////
    private static function mixing($league)
    {
        $leagueId = pageSegment(3);
        $entry_number = isset($_GET['num']) ? $_GET['num'] : 0;
        $orgId = $league['organizationID'];

        $data = self::$fanvictor->getEnterMixingGameData($leagueId, $entry_number);

        $league = self::$fanvictor->parseLeagueData($league);
        $aPool = $data['pool'];
        $aAllFights = $data['fights'];
        $aRounds = $data['rounds'];
        $aPositions = $data['positions'];
        $aLineups = $data['lineup'];
        $aTeams = $data['teams'];
        $indicators = $data['indicators'];
        $playerIdPicks = $data['playerIdPicks'];
        $otherLeagues = $data['otherLeagues'];
        $aPlayers = $data['players'];
        $aSports = $data['aSports'];
        $aPlayers = self::$players->parseMixingPlayersData($aPlayers);

        // count salary
        $salary_remaining = array();
        ksort($aSports);
        ksort($aAllFights);
        $aSportKeys = array_keys($aSports);
        $first_sports_id = $aSportKeys[0];
        foreach ($aSportKeys as $sport_id)
        {
            $salary = 0;
            foreach ($aPool as $pool)
            {
                if ($pool['organization'] == $sport_id)
                {
                    $salary = $pool['salary_remaining'];
                    break;
                }
            }
            $salary_remaining[$sport_id] = round($salary);
        }
        $first_salary = $salary_remaining[$first_sports_id];
        $salary_remaining = json_encode($salary_remaining);

        include FANVICTOR__PLUGIN_DIR_VIEW_ELEMENT . 'gametype/mixing.php';
    }

    //////////////////////end mixing sport//////////////////////
    
    //////////////////////bracket//////////////////////
    private static function bracket($league)
    {
        //get prams
        $params = $_POST;
        $entry_number = !empty($params['entry_number']) ? $params['entry_number'] : 1;

        //load data
        $data = self::$fanvictor->getBracketGame($league['leagueID'], $entry_number);
        $team_groups = $data['team_groups'];
        $my_picks = $data['my_picks'];
        list($group_left, $group_right) = self::$fanvictor->bracketGroupTeam($team_groups);

        //view
        include FANVICTOR__PLUGIN_DIR_VIEW_ELEMENT . 'gametype/bracket.php';
    }
    //////////////////////end bracket//////////////////////
    
    //////////////////////round pick em//////////////////////
    private static function validateEnterPickContest($league)
    {
        $leagueID = pageSegment(3);
        $entry_number = isset($_GET['num']) ? $_GET['num'] : 0;
        $live_entry = isset($_GET['liveentry']) ? $_GET['liveentry'] : 0;
        
        $value = self::$fanvictor->validEnterNormalGame($leagueID);
        switch($value)
        {
            case 3:
                FV_Redirect(FANVICTOR_URL_CONTEST.$leagueID, null, true);
                break;
            case 5:
                FV_Redirect(FANVICTOR_URL_GAME.$leagueID.'/?num='.$entry_number, null, true);
                break;
            case 6:
                FV_Redirect(FANVICTOR_URL_CREATE_CONTEST, __('You can not edit started game', 'fantasy-sports'), true);
                break;
            case 7:
                FV_Redirect(FANVICTOR_URL_GAME.$leagueID.'/?num='.$entry_number, null, true);
                break;
        }
        if(!self::$payment->isUserEnoughMoneyToJoin($league['entry_fee'], $leagueID, $entry_number,$league['multi_entry']))
        {
            FV_Redirect(FANVICTOR_URL_ADD_FUNDS, __('You do not have enough funds to enter. Please add funds', 'fantasy-sports'),true);
        }
        else if(isset($league['gameType']) && $league['gameType'] == 'PICKSQUARES')
        {
            FV_Redirect(FANVICTOR_URL_GAME.$leagueID.'/?num='.$entry_number, null, true);
        }
    }
    
    private static function roundPickem($league)
    {
        $leagueID = pageSegment(3);
        $entry_number = isset($_GET['num']) ? $_GET['num'] : 0;
        
        $data = self::$fanvictor->getRoundPickemContest($leagueID, $entry_number);
        $fights = $data['fights'];
        $predict_matches = $data['predict_matches'];
        $current_week = $data['current_week'];
        
        include FANVICTOR__PLUGIN_DIR_VIEW_ELEMENT.'gametype/roundpickem.php';
    }
    //////////////////////end round pick em//////////////////////
    
    //////////////////////pick em//////////////////////
    private static function pickem($league)
    {
        $leagueID = pageSegment(3);
        $entry_number = isset($_GET['num']) ? $_GET['num'] : 0;
        
        $data = self::$fanvictor->getEnterNormalGameData($leagueID, $entry_number);
        $aLeague = $data['league'];
        $aPool = $data['pool'];
        $otherLeagues = $data['otherLeagues'];
        $aFights = $data['fights'];
        $aMethods = $data['methods'];
        $aMinutes = $data['minutes'];
        $aRounds = $data['rounds'];
        $aPlayers = $data['players'];
        $pickInfo = $data['pickInfo'];
        if($pickInfo){
            $pickInfo = $pickInfo['new_tie_breaker'];
            $pickInfo = json_decode($pickInfo,true);
        }

        include FANVICTOR__PLUGIN_DIR_VIEW_ELEMENT.'gametype/pickem.php';
    }
    //////////////////////end pick em//////////////////////
    
    //////////////////////pick squares//////////////////////
    private static function picksquares($league)
    {
        $league_id = pageSegment(3);
        $entry_number = isset($_GET['num']) ? $_GET['num'] : 0;
        
        $data = self::$fanvictor->getEnterNormalGameData($league_id, $entry_number);
        
        $aFights = $data['fights'];
        $aPickSquare = $data['picksquares'];
        $picksquare = '';
        $userSquares = '';
        $payoutPickSquare = json_decode($league['picksquares_payouts'],true);
        if(!empty($aPickSquare)){
            $picksquare = $aPickSquare['pick_squares'];
            $userSquares = $aPickSquare['user_squares'];
        }
        if(empty($userSquares)){
            $arr1 = range(0, 9);
            $arr2 = range(0, 9);
            shuffle($arr1);
            shuffle($arr2);
            $userSquares[] = $arr1;
            $userSquares[] = $arr2;
            $userSquares = json_encode($userSquares);
        }
        include FANVICTOR__PLUGIN_DIR_VIEW_ELEMENT.'gametype/picksquares.php';
    }
    //////////////////////end pick squares//////////////////////
    
    //////////////////////pickultimate//////////////////////
    private static function pickultimate($league)
    {
        $league_id = pageSegment(3);
        $entry_number = isset($_GET['num']) ? $_GET['num'] : 0;
        
        $data = self::$fanvictor->getEnterNormalGameData($league_id, $entry_number);
        $otherLeagues = $data['otherLeagues'];
        $fights = $data['fights'];

        include FANVICTOR__PLUGIN_DIR_VIEW_ELEMENT.'gametype/pickultimate.php';
    }
    //////////////////////end pickultimate//////////////////////
    
    //////////////////////goliath//////////////////////
    private static function validateEnterGoliath($league, $entry_number)
    {
        $data = self::$fanvictor->validateEnterGoliath($league['leagueID'], $entry_number);
        if(!$data['success'])
        {
            switch ($data['code']) {
                case 1:
                    $message = __('Contest was ended', 'fantasy-sports');
                    break;
                case 2:
                    $message = __('There are live matches now, you can only pick after live matches finish', 'fantasy-sports');
                    break;
                case 3:
                    $message = __('Sorry! You were kicked', 'fantasy-sports');
                    break;
                case 4:
                    $message = __('Sorry! You cannot re-up at this time', 'fantasy-sports');
                    break;
                default :
                    $message = __('Unknown error', 'fantasy-sports');
            }
            FV_Redirect(FANVICTOR_URL_LOBBY, $message, true);
        }
    }

    private static function goliath($league)
    {
        $league_id = $league['leagueID'];
        $entry_number = isset($_GET['num']) ? $_GET['num'] : 0;
        
        $data = self::$fanvictor->getGoliathContest($league_id, $entry_number);
        $fights = $data['fights'];
        $available_max_pass = $data['survivor_available_max_pass'];
        $available_pass = $data['survivor_available_pass'];
        
        include FANVICTOR__PLUGIN_DIR_VIEW_ELEMENT.'gametype/goliath.php';
    }
    //////////////////////end goliath//////////////////////
    
    //////////////////////minigoliath//////////////////////
    private static function validateEnterMiniGoliath($league, $entry_number)
    {
        $data = self::$fanvictor->validateEnterMiniGoliath($league['leagueID'], $entry_number);
        if(!$data['success'])
        {
            switch ($data['code']) {
                case 1:
                    $message = __('Contest was ended', 'fantasy-sports');
                    break;
                case 2:
                    $message = __('There are live matches now, you can only pick after live matches finish', 'fantasy-sports');
                    break;
                case 3:
                    $message = __('Sorry! You were kicked', 'fantasy-sports');
                    break;
                default :
                    $message = __('Unknown error', 'fantasy-sports');
            }
            FV_Redirect(FANVICTOR_URL_LOBBY, $message, true);
        }
    }
    
    private static function minigoliath($league)
    {
        $league_id = $league['leagueID'];
        $entry_number = isset($_GET['num']) ? $_GET['num'] : 0;
        
        $data = self::$fanvictor->getMiniGoliathContest($league_id, $entry_number);
        $fights = $data['fights'];
        $entry_number = $data['entry_number'];
        
        include FANVICTOR__PLUGIN_DIR_VIEW_ELEMENT.'gametype/minigoliath.php';
    }
    //////////////////////end minigoliath//////////////////////
}

?>