<?php

class FlutterWave {

    private  $merchantKey;
    private  $apiKey;
    private  $env = "staging";
    private  $card = array();
    private  $url = '';
            
    private  $resources = array(
        "staging" => array(
            'tokenize' => "http://staging1flutterwave.co:8080/pwc/rest/card/mvva/tokenize/",
            'charge' => "http://staging1flutterwave.co:8080/pwc/rest/card/mvva/pay/",
            'validate' => "http://staging1flutterwave.co:8080/pwc/rest/card/mvva/pay/validate/",
            "preauth" => "http://staging1flutterwave.co:8080/pwc/rest/card/mvva/preauthorize/",
            "capture" => "http://staging1flutterwave.co:8080/pwc/rest/card/mvva/capture/",
            "refund" => "http://staging1flutterwave.co:8080/pwc/rest/card/mvva/refund/",
            "status" => "http://staging1flutterwave.co:8080/pwc/rest/card/mvva/status",
            "linking"=>"http://staging1flutterwave.co:8080/pwc/rest/pay/linkaccount",
            "pay_validate"=>"http://staging1flutterwave.co:8080/pwc/rest/pay/linkaccount/validate",
            "unlink_account"=>"http://staging1flutterwave.co:8080/pwc/rest/pay/unlinkaccount",
            "pay"=>"http://staging1flutterwave.co:8080/pwc/rest/pay/send",
            "list_bank"=>"http://staging1flutterwave.co:8080/pwc/rest/fw/banks/"
        ),
        "production" => array(
            'tokenize' => "https://prod1flutterwave.co:8181/pwc/rest/card/mvva/tokenize/",
            'charge' => "https://prod1flutterwave.co:8181/pwc/rest/card/mvva/pay/",
            'validate' => "https://prod1flutterwave.co:8181/pwc/rest/card/mvva/pay/validate/",
            "preauth" => "https://prod1flutterwave.co:8181/pwc/rest/card/mvva/preauthorize/",
            "capture" => "https://prod1flutterwave.co:8181/pwc/rest/card/mvva/capture/",
            "refund" => "https://prod1flutterwave.co:8181/pwc/rest/card/mvva/refund/",
            "status" => "https://prod1flutterwave.co:8181/pwc/rest/card/mvva/status"
        )
    );
    
    public function __construct()
    {
        if(get_option('fanvictor_flutterwave_mode') == 1)
        {
            $this->env = "production";
        }
    }

    public  function encrypt3Des($data, $key) {
        //Generate a key from a hash
        $key = md5(utf8_encode($key), true);

        //Take first 8 bytes of $key and append them to the end of $key.
        $key .= substr($key, 0, 8);

        //Pad for PKCS7
        $blockSize = mcrypt_get_block_size('tripledes', 'ecb');
        $len = strlen($data);
        $pad = $blockSize - ($len % $blockSize);
        $data = $data . str_repeat(chr($pad), $pad);

        //Encrypt data
        $encData = mcrypt_encrypt('tripledes', $key, $data, 'ecb');

        //return $this->strToHex($encData);

        return base64_encode($encData);
    }

    public  function decrypt3Des($data, $secret) {
        //Generate a key from a hash
        $key = md5(utf8_encode($secret), true);

        //Take first 8 bytes of $key and append them to the end of $key.
        $key .= substr($key, 0, 8);

        $data = base64_decode($data);

        $data = mcrypt_decrypt('tripledes', $key, $data, 'ecb');

        $block = mcrypt_get_block_size('tripledes', 'ecb');
        $len = strlen($data);
        $pad = ord($data[$len - 1]);

        return substr($data, 0, strlen($data) - $pad);
    }

    public  function setMerchantCredentials($merchant_key, $api_key) {
        $this->merchantKey = $merchant_key;
        $this->apiKey = $api_key;
    }

    public  function setCardForCharge($card_no, $cvv, $expiry_month, $expiry_year) {
        $this->card['card_no'] = $card_no;
        $this->card['cvv'] = $cvv;
        $this->card['expiry_month'] = $expiry_month;
        $this->card['expiry_year'] = $expiry_year;
    }

    public  function charge($amount, $custId, $currency, $country, $authModel, $narration = "", $responseUrl = "") {
//    FlutterValidator::validateClientCredentialsSet();
        $card = $this->card;
        $key = $this->apiKey;
        $amount = $this->encrypt3Des($amount, $key);
        $custId = $this->encrypt3Des($custId, $key);
        $currency = $this->encrypt3Des($currency, $key);
        $authModel = $this->encrypt3Des($authModel, $key);
        $narration = $this->encrypt3Des($narration, $key);
        $responseUrl = $this->encrypt3Des($responseUrl, $key);
        $cardNo = $this->encrypt3Des($card['card_no'], $key);
        $expiryMonth = $this->encrypt3Des($card['expiry_month'], $key);
        $expiryYear = $this->encrypt3Des($card['expiry_year'], $key);
        $country = $this->encrypt3Des($country, $key);
        $cardType = "";
        if (isset($card['card_type']) && !empty($card['card_type'])) {
            $cardType = FlutterEncrypt::encrypt3Des($card['card_type'], $key);
        }
        $pin = "";
        if (isset($card['pin']) && !empty($card['pin'])) {
            $pin = FlutterEncrypt::encrypt3Des($card['pin'], $key);
        }
        $bvn = "";
        if (isset($card['bvn']) && !empty($card['bvn'])) {
            $bvn = $this->encrypt3Des($card['bvn'], $key);
        }
        $cvv = $this->encrypt3Des($card['cvv'], $key);
        $merchantKey = $this->merchantKey;

        $this->url = $this->resources[$this->env]['charge'];
        $resp = array(
            "merchantid" => $merchantKey,
            "amount" => $amount,
            "custid" => $custId,
            "currency" => $currency,
            "authmodel" => $authModel,
            "narration" => $narration,
            "responseurl" => $responseUrl,
            "cardno" => $cardNo,
            "cardtype" => $cardType,
            "cvv" => $cvv,
            "expirymonth" => $expiryMonth,
            "country" => $country,
            "expiryyear" => $expiryYear,
            "pin" => $pin,
            "bvn" => $bvn,
        );

       return $this->_doPost($resp);
    }

    public function _doPost($query) {

        $query = json_encode($query);
        
        $ch = curl_init();
        curl_setopt($ch, CURLOPT_URL, $this->url);
        curl_setopt($ch, CURLOPT_CONNECTTIMEOUT, 30);
        curl_setopt($ch, CURLOPT_TIMEOUT, 30);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
        curl_setopt($ch, CURLOPT_HEADER, 0);
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, 0);

        curl_setopt($ch, CURLOPT_POSTFIELDS, $query);
        curl_setopt($ch, CURLOPT_HTTPHEADER, array(                                                                          
    'Content-Type: application/json',                                                                                
    'Content-Length: ' . strlen($query))                                                                       
); 

        curl_setopt($ch, CURLOPT_POST, 1);

        if (!($data = curl_exec($ch))) {
            return false;
        }
        curl_close($ch);
        unset($ch);
        $data = json_decode($data,true);
        if(isset($data['status']) || isset($data['data'])){
            return $data;
        }

    }
	public function checkResponse($response){
		if(!$response){
			return false;
		}
		
		$status_success_code = array(
			"00","02","0"
		);
		if(isset($response['status']) && $response['status'] == 'success' &&isset($response["data"]["responsecode"]) && in_array($response["data"]["responsecode"],$status_success_code)){
			return true;
		}
		return false;
	}
	public function pay(
	$merchant_account_number,
	$country,
	$currency,
	$transferamount,
	$narration,
	$recipientname,
	$sendername,
	$recipientaccount,
        $otp_params,$dest_bankcode){
//		$dest_bankcode = "044";
		// linking account
		$response['success'] = 1;
		$this->url = $this->resources[$this->env]['linking'];
		$merchant_api = $this->apiKey;
		$merchant_key = $this->merchantKey; // merchant id
		$encryptedMerchantAccount =  $this->encrypt3Des($merchant_account_number, $merchant_api); 
		
		$linking_request = array(
		'accountnumber'=>$encryptedMerchantAccount,
		'merchantid'=>$merchant_key
		);
//		$raw_linking_request = array(
//			'accountnumber'=>$merchant_account_number,
//			'merchantid'=>$merchant_key
//		);
		$response_linking =   $this->_doPost($linking_request);
		$is_linking_success = $this->checkResponse($response_linking);
		// print_r($response_linking);
		if(!$is_linking_success){
			$response['success']= 0;
				$response['mss'] = 'Linking account failed.';
			return $response;
		}
		
		$linkingRef = $response_linking['data']['uniquereference'];
		
		// validation step 1
		$otp = $otp_params['otp1']; //"12345";
		$otpType = $otp_params['otptype1']    ;//"PHONE_OTP";
		
		 $request_validate1 = array(
			"otp"=> $this->encrypt3Des($otp, $merchant_api),
			"relatedreference"=> $this->encrypt3Des($linkingRef, $merchant_api),
			"otptype"=>  $this->encrypt3Des($otpType, $merchant_api),
			"merchantid"=> $merchant_key

		);
//		$raw_request_validate_1 = array(
//			"merchantid"=> $merchant_key,
//			"otp"=> $otp,
//			"relatedreference"=> $linkingRef,
//			"otptype"=>$otpType,
//		);
		$this->url = $this->resources[$this->env]['pay_validate'];

		$reseponse_step1 = $this->_doPost($request_validate1);
		//  print_r($reseponse_step1);
		$is_step1_success  = $this->checkResponse($reseponse_step1);
		if(!$is_step1_success){
			$response['success']= 0;
				$response['mss'] = 'Validate 1 failed.';
			return $response;
		}
		
		// validation step 2
		$otp = $otp_params['otp2'];  //"1.0";
		$otpType = $otp_params['otptype2']  ;//"ACCOUNT_DEBIT";
		$request_validate2 = array(
			"merchantid"=> $merchant_key,
			"otp"=> $this->encrypt3Des($otp, $merchant_api),
			"relatedreference"=> $this->encrypt3Des($linkingRef, $merchant_api),
			"otptype"=>$this->encrypt3Des($otpType, $merchant_api),


		);
//		$raw_request_validate_2 = array(
//			"merchantid"=> $merchant_key,
//			"otp"=> $otp,
//			"relatedreference"=> $linkingRef,
//			"otptype"=>$otpType,
//		);
		
		$this->url = $this->resources[$this->env]['pay_validate'];

		$reseponse_step2 = $this->_doPost($request_validate2);
//		print_r($reseponse_step2);
		$is_step2_success  = $this->checkResponse($reseponse_step2);
		if(!$is_step2_success){
			$response['success']= 0;
				$response['mss'] = 'Validate step 2 failed.';
			return $response;
		}
		
		$accounttoken = $reseponse_step2['data']['accounttoken'];
		// payment
//		$raw_transfer_request = array(
//		  "accounttoken"=> $accounttoken,
//		  "destbankcode"=> $dest_bankcode,
//		  "uniquereference"=> $linkingRef,
//		  "country"=> $country,
//		  "currency"=>$currency ,
//		  "transferamount"=> $transferamount,
//		  "narration"=> $narration,
//		  "recipientname"=> $recipientname,
//		  "sendername"=> $sendername,
//		  "merchantid"=> $merchant_key,
//		  "recipientaccount"=>$recipientaccount,
//		);
//		print_r($raw_transfer_request);
		$transfer_request = array(
		  "accounttoken"=> $this->encrypt3Des($accounttoken,$merchant_api),
		  "destbankcode"=> $this->encrypt3Des($dest_bankcode,$merchant_api),
		  "uniquereference"=> $this->encrypt3Des($linkingRef,$merchant_api),
		  "country"=> $this->encrypt3Des($country,$merchant_api),
		  "currency"=>$this->encrypt3Des($currency,$merchant_api) ,
		  "transferamount"=> $this->encrypt3Des($transferamount,$merchant_api),
		  "narration"=> $this->encrypt3Des($narration,$merchant_api),
		  "recipientname"=> $this->encrypt3Des($recipientname,$merchant_api),
		  "sendername"=> $this->encrypt3Des($sendername,$merchant_api),
		  "merchantid"=> $merchant_key,
		  "recipientaccount"=> $this->encrypt3Des($recipientaccount,$merchant_api),
		);
		
		$this->url = $this->resources[$this->env]['pay'];
		$response_payment = $this->_doPost($transfer_request);
                
		$is_valid_payment = $this->checkResponse($response_payment);

		if(!$is_valid_payment){
			$response['success']= 0;
				$response['mss'] = ' Payment failed.';
			return $response;
		}
     

                $response['success'] = 1;
                $response['data'] =$response_payment['data'] ;
		return $response;
		
	}
	
	public function unlinkAccount($account_number){
		$this->url = $this->resources[$this->env]['unlink_account'];
		$request_unlink = array(
			"merchantid"=> $this->merchantKey,
			"accountnumber"=> $this->encrypt3Des($account_number,$this->apiKey),
			// "country": "(Optional) Encrypted Country (NG|KE)" // Defaults to Nigeria if parameter is not set
		);
		$response_unlink = $this->_doPost($request_unlink);
		$is_success_unlink = $this->checkResponse($response_unlink);
		
		
	}
        
    public function loadBankEnquiry(){
        $this->url = $this->resources[$this->env]['list_bank'];
        $response = $this->_doPost(array());

        if (isset($response['status']) && 'success' === $response['status']) {
            asort($response['data']);

            return $response['data'];
        }

        return array();
    }
  
}

//0690000040, 0690000041, 0690000037
//$g = new FlutterWave();
//$g->setMerchantCredentials("tk_ouGLDKvRJ3", 'tk_2ywNhE7vq8zudOPsoFZ0');
 //$g->pay('0690000040');//0690000040
//$g->unlinkAccount("0690000040");
//$g->setCardForCharge('5043342567607506', '248', 01, 18);
//$g->charge(100, "111", 'USD', 'US','NOAUTH');